@@ -35,7 +35,7 @@ monitor_aqi <- function(
   monitor,
   version = c("pm", "pmAsian", "ozone"),
   includeShortTerm = FALSE,
-  NAAQS = c("PM2.5", "PM2.5_2024")
+  NAAQS = c("PM2.5_2024", "PM2.5")
 ) {
 
   parameterName <- "PM2.5"
